@@ -5,7 +5,7 @@
 ;; Author: J.D. Smith <jdtsmith@gmail.com>
 ;; URL: https://github.com/jdtsmith/kind-icon
 ;; Package-Requires: ((emacs "27.1") svg-lib)
-;; Version: 0.1.7
+;; Version: 0.1.8
 ;; Keywords: completion
 
 ;; kind-icon is free software: you can redistribute it
@@ -88,6 +88,7 @@ An vector of two alist for non-terminal and terminal.")
     (boolean "b" :icon "circle-half-full" :face font-lock-builtin-face)
     (class "c" :icon "view-grid-plus-outline" :face font-lock-type-face)
     (color "#" :icon "palette" :face success)
+    (command "cm" :icon "code-greater-than" :face default)
     (constant "co" :icon "lock-remove-outline" :face font-lock-constant-face)
     (constructor "cn" :icon "table-column-plus-after" :face font-lock-function-name-face)
     (enummember "em" :icon "format-list-checks" :face font-lock-builtin-face)
@@ -99,6 +100,7 @@ An vector of two alist for non-terminal and terminal.")
     (interface "if" :icon "application-brackets-outline" :face font-lock-type-face)
     (keyword "kw" :icon "key-variant" :face font-lock-keyword-face)
     (macro "mc" :icon "lambda" :face font-lock-keyword-face)
+    (magic "ma" :icon "auto-fix" :face font-lock-builtin-face)
     (method "m" :icon "function-variant" :face font-lock-function-name-face)
     (function "f" :icon "function" :face font-lock-function-name-face)
     (module "{" :icon "file-code-outline" :face font-lock-preprocessor-face)
@@ -222,11 +224,9 @@ float FRAC."
   "Preview all kind icons.
 In the process, svg-lib also downloads and caches them."
   (interactive)
-  (with-current-buffer (get-buffer-create "*kind-icon-preview*")
+  (with-current-buffer-window "*kind-icon-preview*" nil nil
     (font-lock-mode 0)
-    (view-buffer-other-window (current-buffer))
     (let ((inhibit-read-only t))
-      (erase-buffer)
       (insert "kind-icon badges\n\ntxt icn\tkind\n")
       (mapc (lambda (k)
 	      (apply 'insert
@@ -241,7 +241,7 @@ In the process, svg-lib also downloads and caches them."
     (help-mode)))
 
 (defun kind-icon-formatted (kind)
-  "Return a formatted kind badge, either icon or text abbreviation.
+  "Return a formatted KIND badge, either icon or text abbreviation.
 Caches this badge in `kind-icon--cache', and returns the cached
 value, if set.  If no matching kind is specified, returns a `??'
 warning label.  For the foreground color of the badge, uses the
@@ -261,11 +261,12 @@ background-color."
 	(if-let ((map (assq kind kind-icon-mapping))
 		 (plist (cddr map)))
 	    (let* ((kind-face (plist-get plist :face))
-		   (col (if kind-face
-			    (face-attribute kind-face :foreground nil t)
-			  (if kind-icon-default-face
-			      (face-attribute kind-icon-default-face :foreground nil t)
-			    (frame-parameter nil 'foreground-color))))
+		   (col (or
+			 (and kind-face
+			      (face-attribute kind-face :foreground nil t))
+			 (and kind-icon-default-face
+			      (face-attribute kind-icon-default-face :foreground nil t))
+			 (frame-parameter nil 'foreground-color)))
 		   (kind-face-bg (and kind-face
 				      (face-attribute kind-face :background nil t)))
 		   (default-bg (if kind-icon-default-face
